package com.gree.mall.manager.logic.notice;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.gree.mall.manager.bean.admin.AdminUserCom;
import com.gree.mall.manager.bean.notice.NoticeWebsitBean;
import com.gree.mall.manager.bean.notice.NoticeWebsitRecordVO;
import com.gree.mall.manager.bean.notice.NoticeWebsitVO;
import com.gree.mall.manager.bean.workorder.WebsitDispatchVO;
import com.gree.mall.manager.commonmapper.NoticeRecordBeanMapper;
import com.gree.mall.manager.logic.common.CommonLogic;
import com.gree.mall.manager.plus.entity.AdminWebsit;
import com.gree.mall.manager.plus.entity.NoticeWebsit;
import com.gree.mall.manager.plus.entity.NoticeWebsitRecord;
import com.gree.mall.manager.plus.service.AdminWebsitService;
import com.gree.mall.manager.plus.service.NoticeWebsitRecordService;
import com.gree.mall.manager.plus.service.NoticeWebsitService;
import com.gree.mall.manager.zfire.bean.ZfireParamBean;
import com.gree.mall.manager.zfire.util.FieldUtils;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

@Service
@Slf4j
public class NoticeWebsitLogic {

    @Autowired
    CommonLogic commonLogic;

    @Autowired
    NoticeRecordBeanMapper noticeRecordMapper;

    @Autowired
    NoticeWebsitService noticeWebsitService;

    @Autowired
    AdminWebsitService adminWebsitService;

    @Autowired
    NoticeWebsitRecordService noticeWebsitRecordService;


    public IPage<NoticeWebsitVO> list(Page page, ZfireParamBean zfireParam) {
        //获取当前登录企业id
        AdminUserCom adminUser = commonLogic.getAdminUser();

        List<String> adminCompanyIds = adminUser.getCompanyWechatIds();
        //1.组装查询条件
        zfireParam = FieldUtils.supplyParam(zfireParam, NoticeWebsitVO.class,adminUser);

        IPage<NoticeWebsitVO> websitDispatchVOIPage = noticeRecordMapper.listNoticeWebsit(new Page(zfireParam.getPageNum(), zfireParam.getPageSize()), zfireParam, adminCompanyIds);

        return websitDispatchVOIPage;
    }

    public NoticeWebsit detail(String id) {
        NoticeWebsit noticeWebsit = noticeWebsitService.getById(id);
        return noticeWebsit;
    }

    public void add(NoticeWebsitBean noticeBean) {
        AdminUserCom adminUser = commonLogic.getAdminUser();
        noticeBean.setAdminCompanyId(adminUser.getCompanyWechatId());
        noticeBean.setAdminCompanyName(adminUser.getCompanyName());
        noticeBean.insert();

        List<NoticeWebsitRecord> noticeWebsitRecords = new ArrayList<>();


        for (String websitId : noticeBean.getWebsitIds()) {
            AdminWebsit adminWebsit = adminWebsitService.getById(websitId);
            NoticeWebsitRecord noticeWebsitRecord = new NoticeWebsitRecord();
            noticeWebsitRecord.setAdminWebsitId(websitId);
            noticeWebsitRecord.setAdminWebsitName(adminWebsit.getName());
            noticeWebsitRecord.setAdminCompanyId(adminWebsit.getName());
            noticeWebsitRecord.setAdminCompanyName(adminWebsit.getName());
            noticeWebsitRecord.setAdminCompanyId(adminUser.getCompanyWechatId());
            noticeWebsitRecord.setAdminCompanyName(adminUser.getCompanyName());

            noticeWebsitRecords.add(noticeWebsitRecord);
        }

        noticeWebsitRecordService.saveBatch(noticeWebsitRecords);
    }

    public void update(NoticeWebsitBean noticeBean) {

        AdminUserCom adminUser = commonLogic.getAdminUser();
        noticeBean.setAdminCompanyId(adminUser.getCompanyWechatId());
        noticeBean.setAdminCompanyName(adminUser.getCompanyName());
        noticeBean.updateById();

        List<NoticeWebsitRecord> noticeWebsitRecords = new ArrayList<>();

        noticeWebsitRecordService.lambdaUpdate()
                .eq(NoticeWebsitRecord::getNoticeWebsitId,noticeBean.getNoticeWebsitId())
                .remove();

        for (String websitId : noticeBean.getWebsitIds()) {
            AdminWebsit adminWebsit = adminWebsitService.getById(websitId);
            NoticeWebsitRecord noticeWebsitRecord = new NoticeWebsitRecord();
            noticeWebsitRecord.setAdminWebsitId(websitId);
            noticeWebsitRecord.setAdminWebsitName(adminWebsit.getName());
            noticeWebsitRecord.setAdminCompanyId(adminWebsit.getName());
            noticeWebsitRecord.setAdminCompanyName(adminWebsit.getName());
            noticeWebsitRecord.setAdminCompanyId(adminUser.getCompanyWechatId());
            noticeWebsitRecord.setAdminCompanyName(adminUser.getCompanyName());

            noticeWebsitRecords.add(noticeWebsitRecord);
        }

        noticeWebsitRecordService.saveBatch(noticeWebsitRecords);
    }

    public void ofOrSend(String id, String status) {
        NoticeWebsit noticeWebsit = noticeWebsitService.getById(id);
        noticeWebsit.setStatus(status);
        noticeWebsit.updateById();
    }

    public IPage<NoticeWebsitRecordVO> listWebsit(Page page, ZfireParamBean zfireParam) {
        //获取当前登录企业id
        AdminUserCom adminUser = commonLogic.getAdminUser();

        List<String> adminCompanyIds = adminUser.getCompanyWechatIds();
        //1.组装查询条件
        zfireParam = FieldUtils.supplyParam(zfireParam, NoticeWebsitRecordVO.class,adminUser);

        IPage<NoticeWebsitRecordVO> noticeWebsitRecordVOIPage = noticeRecordMapper.listWebsit(new Page(zfireParam.getPageNum(), zfireParam.getPageSize()), zfireParam, adminCompanyIds);

        return noticeWebsitRecordVOIPage;
    }
}
